//********************************************************************************************
// MM_stewart_find_servo_ranges2.ino
// RC Model Servo range finder.
// Press 0 - 5 to sweep a servo full range and return to middle
// Servos are positioned with "servo[j].write(microseconds)" and checked for end of available travel.
// Servo positions are returned in °rotation and corresponding microsecond value
// The results are output in the format:
// Servo 0:	 min = 553	 mid = 1488	 max = 2399
// Servo 1:	 min = 553	 mid = 1488	 max = 2399
// Servo 2:	 min = 553	 mid = 1488	 max = 2399
// Servo 3:	 min = 553	 mid = 1488	 max = 2399
// Servo 4:	 min = 553	 mid = 1488	 max = 2399
// Servo 5:	 min = 553	 mid = 1488	 max = 2399
//********************************************************************************************

#include <Servo.h>
Servo servo[6];                                 // 6 element servo array, variable name is "servo". Can be any valid variable name.
int i, j, k;
char fromSim;                                   // Data from sim in format: A<Axis1a>B<Axis2a>C<Axis3a>D<Axis4a>E<Axis5a>F<Axis6a>X (eg. A127B127C127D127E127F127X)
int rawServoData[6];                            // 6 element array to hold raw servo data as read from sim.
int servoPos;                                   // stores the read servo pos
int servoData[6];                               // 6 element array to hold servo positoin data ready to write to servos.
int servoMin[6], servoMax[6], servoMid[6];      // stores the minimum and maxmum microseconds


void setup()
{
  for (i = 0; i <= 5; i++) {                    // loop to set up 6 servos
    servo[i].attach(i + 4);                     // attach servos 0 - 5 to pins 4 - 9
    servo[i].write(90);                         // set each servo to mid point (90°)
  }

  Serial.begin(57600);                             // opens serial port at a baud rate of 57600
  Serial.println("MM_stewart_find_servo_ranges2");  //report the current loaded software
}



void loop() {

  if (Serial.available() > 0) {
    j = Serial.parseInt();
    //i = 1500;
    //servo[j].write(90);                               // Write the  values to a servo.
    servoMin[j] = findMin(j);							// function to find min position
    servoMax[j] = findMax(j);							// function to find max position
    servoMid[j] = findMid(j);							// function to find mid position

    for (i = 0; i <= 5; i++) {							// print out the servo min, mid and max values in microseconds 
      Serial.print("Servo ");							// Values can be used to map the ranges for each servo in the 
	  Serial.print(i);									// "MM_stewart_test4.ino" code for testing on 6DOF on mini RC rigs.
      Serial.print(":\t min = ");
      Serial.print(servoMin[i]);
      Serial.print("\t mid = ");
      Serial.print(servoMid[i]);
      Serial.print("\t max = ");
      Serial.println(servoMax[i]);
    }
  }
  //servo[j].write(90);                                                   // return servo to 90°
}

int findMin(int s) {
  int q = 1000;
  while (servo[s].read() > 0) {
    q--;
    delay(2);
    servo[s].write(q);
  }
  return q;
}

int findMid(int s) {
  int q = 1500;
  while (servo[s].read() < 89) {
    q++;
    delay(2);
    servo[s].write(q);
  }
  while (servo[s].read() > 91) {
    q--;
    delay(2);
    servo[s].write(q);
  }
  return q;
}




int findMax(int s) {
  int q = 2000;
  while (servo[s].read() < 180) {
    q++;
    delay(2);
    servo[s].write(q);
  }
  return q;
}

/*

*/
